.. _api:

API
===

riccati.chebutils module
------------------------

.. automodule:: riccati.chebutils
   :members:
   :undoc-members:
   :show-inheritance:

riccati.solversetup module
--------------------------

.. automodule:: riccati.solversetup
   :members:
   :undoc-members:
   :show-inheritance:

riccati.stepsize module
-----------------------

.. automodule:: riccati.stepsize
   :members:
   :undoc-members:
   :show-inheritance:

riccati.step module
-------------------

.. automodule:: riccati.step
   :members:
   :undoc-members:
   :show-inheritance:


riccati.evolve module
---------------------

.. automodule:: riccati.evolve
   :members:
   :undoc-members:
   :show-inheritance:
